module Chromate

  # Commonly supported effect sequences
  EFFECTS = {
    :off       => Effect.new(0),
    :bold      => Effect.new(1),
    :underline => Effect.new(4),
    :blink     => Effect.new(5),
    :negative  => Effect.new(7)
  }

  # Valid effect sequences
  VALID_EFFECTS = EFFECTS.map { |n, e| e.to_i }

  OFF = EFFECTS[:off]
  const_set(:Effects, Module.new do
    Chromate::EFFECTS.each do |name, effect|
      const_set(name.to_s.upcase, effect)
    end
  end)

  # Names for common colors
  COLOR_NAMES = {
    :black        => 0,
    :dark_red     => 1,
    :dark_green   => 2,
    :dark_yellow  => 3,
    :dark_blue    => 4,
    :dark_magenta => 5,
    :dark_cyan    => 6,
    :silver       => 7,
    :gray         => 8,
    :grey         => 8,
    :red          => 9,
    :green        => 10,
    :yellow       => 11,
    :blue         => 12,
    :magenta      => 13,
    :cyan         => 14,
    :white        => 15
  }

  # All xterm-256 colors
  COLORS = (0..255).map { |i| Color.new(i) }

  # Greyscale colors
  GREYSCALE_COLORS = COLORS[231..255] + 
    [COLORS[0], COLORS[7], COLORS[8], COLORS[15]]

  # Colors supported by the host environment
  SUPPORTED_COLORS = case RbConfig::CONFIG['host_os']
  when /darwin|linux|arch|solaris|sunos|(free|net|open)bsd/i
    COLORS[0..`tput colors`.to_i - 1]
  when /mswin|windows/i
    begin
      require 'win32console'
      COLORS[0..15]
    rescue LoadError
      []
    end
  else
    []
  end

end